OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informationen zur CPU nicht verfügbar",
    "Load average: {cpu} (last minute)" : "Durchschnittliche Last: {cpu} (letzte Minute)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Gesamt: {memTotalBytes}/Aktuelle Nutzung: {memUsageBytes}",
    "RAM info not available" : "Informationen zum RAM nicht verfügbar",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Gesamt: {swapTotalBytes}/Aktuelle Nutzung: {swapUsageBytes}",
    "SWAP info not available" : "Informationen zum SWAP nicht verfügbar",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "⌘-C zum Kopieren drücken.",
    "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
    "System" : "System",
    "Monitoring" : "Information",
    "Monitoring app with useful server information" : "Monitoring-App mit nützlichen Serverinformationen",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Zeigt nützliche Informationen des Servers an wie z. B. CPU-Last, Arbeitsspeicherauslastung, Massenspeicherauslastung, Anzahl der Benutzer, usw.",
    "Operating System:" : "Betriebssystem:",
    "CPU:" : "Prozessor:",
    "Unknown Processor" : "Unbekannter Prozessor",
    "Memory:" : "Speicher:",
    "Server time:" : "Server-Zeit:",
    "Uptime:" : "Betriebszeit:",
    "Temperature" : "Temperatur",
    "Load" : "Auslastung",
    "Memory" : "Speicher",
    "Disk" : "Festplatte",
    "Mount:" : "Mount:",
    "Filesystem:" : "Dateisystem:",
    "Size:" : "Größe:",
    "Available:" : "Verfügbar:",
    "Used:" : "Verwendet:",
    "You will get a notification once one of your disks is nearly full." : "Du erhältst eine Benachrichtigung, sobald eines deiner Speichermedien fast voll ist.",
    "Files:" : "Dateien:",
    "Storages:" : "Speicher:",
    "Free Space:" : "Freier Speicherplatz:",
    "Network" : "Netzwerk",
    "Hostname:" : "Hostname:",
    "DNS:" : "DNS:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Geschwindigkeit:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktive Benutzer",
    "Total users:" : "Benutzer gesamt:",
    "24 hours:" : "24 Stunden:",
    "1 hour:" : "1 Stunde:",
    "5 mins:" : "5 Minuten:",
    "Shares" : "Freigaben",
    "Users:" : "Benutzer:",
    "Groups:" : "Gruppen:",
    "Links:" : "Links:",
    "Emails:" : "E-Mails:",
    "Federated sent:" : "Federated gesendet:",
    "Federated received:" : "Federated empfangen:",
    "Talk conversations:" : "Talk-Unterhaltungen:",
    "PHP" : "PHP",
    "Version:" : "Version:",
    "Memory limit:" : "Speicherlimit:",
    "Max execution time:" : "Maximale Ausführungszeit:",
    "Upload max size:" : "Maximale Größe zum Hochladen:",
    "Extensions:" : "Erweiterungen:",
    "Unable to list extensions" : "Erweiterungen konnten nicht aufgeführt werden",
    "Database" : "Datenbank",
    "Type:" : "Art:",
    "External monitoring tool" : "Externes Überwachungsprogramm",
    "You can connect an external monitoring tool by using this end point:" : "Durch Verwendung des folgenden Zugangspunktes kann ein externes Überwachungsprogramm verwendet werden: ",
    "Copy" : "Kopieren",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Wenn du \"?format=json\" am Ende der URL anhängst, erhältst du das Ergebnis in JSON.",
    "To use an access token, please generate one then set it using the following command:" : "Um ein Zugriffstoken zu verwenden, generiere bitte ein Token und lege es mit dem folgenden Befehl fest:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Übergib dann das Token mit dem \"NC-Token\"-Header bei der Abfrage der obigen URL.",
    "Users" : "Benutzer",
    "Groups" : "Gruppen",
    "Links" : "Verknüpfungen",
    "Emails" : "E-Mails",
    "Federated sent" : "Federated gesendet",
    "Federated received" : "Federated empfangen",
    "Talk conversations" : "Talk Unterhaltungen",
    "24 hours" : "24 Stunden",
    "1 hour" : "1 Stunde",
    "5 mins" : "5 Minuten",
    "Copied!" : "Kopiert!",
    "Operating System" : "Betriebssystem",
    "CPU" : "Prozessor",
    "Server time" : "Server-Zeit",
    "Uptime" : "Betriebszeit",
    "Mount" : "Mount",
    "Filesystem" : "Dateisystem",
    "Size" : "Größe",
    "Available" : "Verfügbar",
    "Used" : "Verwendet",
    "Files" : "Dateien",
    "Storages" : "Speicher",
    "Free Space" : "Freier Speicherplatz",
    "Hostname" : "Host-Name",
    "DNS" : "DNS",
    "Gateway" : "Gateway",
    "Status" : "Status",
    "Speed" : "Geschwindigkeit",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Total users" : "Benutzer gesamt",
    "Version" : "Version",
    "Memory limit" : "Speicherlimit",
    "Max execution time" : "Maximale Ausführungszeit",
    "Upload max size" : "Maximale Größe zum Hochladen",
    "Type" : "Typ",
    "You can connect an external monitoring tool by using this end point" : "Du kannst ein externes Überwachungsprogramm mit diesem Zugangspunkt verwenden.",
    "To use an access token, please generate one then set it using the following command" : "Um ein Zugriffstoken zu verwenden, erzeuge bitte eines und lege es dann mit folgendem Befehl fest"
},
"nplurals=2; plural=(n != 1);");
